@@ -33,6 +33,7 @@
 
 #include "capabilities.h"
 #include "clientsideencryption.h"
+#include "clientstatusreporting.h"
 #include "common/utility.h"
 #include "syncfileitem.h"
 
@@ -305,11 +306,18 @@ public:
     [[nodiscard]] PushNotifications *pushNotifications() const;
     void setPushNotificationsReconnectInterval(int interval);
 
+    void trySetupClientStatusReporting();
+
+    void reportClientStatus(const ClientStatusReportingStatus status) const;
+
     [[nodiscard]] std::shared_ptr<UserStatusConnector> userStatusConnector() const;
 
     void setLockFileState(const QString &serverRelativePath,
+                          const QString &remoteSyncPathWithTrailingSlash,
+                          const QString &localSyncPath,
                           SyncJournalDb * const journal,
-                          const SyncFileItem::LockStatus lockStatus);
+                          const SyncFileItem::LockStatus lockStatus,
+                          const SyncFileItem::LockOwnerType lockOwnerType);
 
     SyncFileItem::LockStatus fileLockStatus(SyncJournalDb * const journal,
                                             const QString &folderRelativePath) const;
@@ -373,6 +381,9 @@ protected Q_SLOTS:
     void slotCredentialsAsked();
     void slotDirectEditingRecieved(const QJsonDocument &json);
 
+private slots:
+    void removeLockStatusChangeInprogress(const QString &serverRelativePath, const SyncFileItem::LockStatus lockStatus);
+
 private:
     Account(QObject *parent = nullptr);
     void setSharedThis(AccountPtr sharedThis);
@@ -434,8 +445,12 @@ private:
 
     PushNotifications *_pushNotifications = nullptr;
 
+    std::unique_ptr<ClientStatusReporting> _clientStatusReporting;
+
     std::shared_ptr<UserStatusConnector> _userStatusConnector;
 
+    QHash<QString, QVector<SyncFileItem::LockStatus>> _lockStatusChangeInprogress;
+
     /* IMPORTANT - remove later - FIXME MS@2019-12-07 -->
      * TODO: For "Log out" & "Remove account": Remove client CA certs and KEY!
      *
